diff --git a/lib/hawat/app.py b/lib/hawat/app.py
index 33fa4c5b924326076293c3293a6c47d10d703c6d..3e387e4540fd6547f3118bc4a87903fbe2cd8396 100644
--- a/lib/hawat/app.py
+++ b/lib/hawat/app.py
@@ -90,10 +90,10 @@ def create_app_full(
     :param str config_file: Name of the file containing additional configurations.
     :param str config_env:  Name of the environment variable pointing to file containing configurations.
     :return: Hawat application
-    :rtype: hawat.base.VialApp
+    :rtype: hawat.base.Vial
     """
 
-    app = hawat.base.VialApp(APP_NAME)
+    app = hawat.base.Vial(APP_NAME)
 
     if config_dict and isinstance(config_dict, dict):
         app.config.update(config_dict)
@@ -127,7 +127,7 @@ def create_app():
     variables.
 
     :return: Hawat application
-    :rtype: hawat.base.VialApp
+    :rtype: hawat.base.Vial
     """
     config_name = os.getenv('FLASK_CONFIG', 'default')
     config_file = hawat.config.get_default_config_file()
@@ -147,9 +147,9 @@ def _setup_app_logging(app):
     Setup logging to file and via email for given Hawat application. Logging
     capabilities are adjustable by application configuration.
 
-    :param hawat.base.VialApp app: Hawat application to be modified.
+    :param hawat.base.Vial app: Hawat application to be modified.
     :return: Modified Hawat application
-    :rtype: hawat.base.VialApp
+    :rtype: hawat.base.Vial
     """
     hawat.log.setup_logging_default(app)
     hawat.log.setup_logging_file(app)
@@ -163,9 +163,9 @@ def _setup_app_mailer(app):
     """
     Setup mailer service for Hawat application.
 
-    :param hawat.base.VialApp app: Hawat application to be modified.
+    :param hawat.base.Vial app: Hawat application to be modified.
     :return: Modified Hawat application
-    :rtype: hawat.base.VialApp
+    :rtype: hawat.base.Vial
     """
     hawat.mailer.MAILER.init_app(app)
     app.mailer = hawat.mailer.MAILER
@@ -183,9 +183,9 @@ def _setup_app_core(app):
         * Additional custom Jinja template variables
         * Additional custom Jinja template macros
 
-    :param hawat.base.VialApp app: Hawat application to be modified.
+    :param hawat.base.Vial app: Hawat application to be modified.
     :return: Modified Hawat application
-    :rtype: hawat.base.VialApp
+    :rtype: hawat.base.Vial
     """
     @app.errorhandler(400)
     def eh_badrequest(err):  # pylint: disable=locally-disabled,unused-variable
@@ -514,7 +514,7 @@ def _setup_app_core(app):
             get_datetime_local  = get_datetime_local,
             parse_datetime      = parse_datetime,
 
-            get_datetime_window = hawat.base.VialAppUtils.get_datetime_window,
+            get_datetime_window = hawat.base.VialUtils.get_datetime_window,
 
             get_reporting_interval_name = get_reporting_interval_name,
 
@@ -593,9 +593,9 @@ def _setup_app_db(app):
     """
     Setup application database service for given Hawat application.
 
-    :param hawat.base.VialApp app: Hawat application to be modified.
+    :param hawat.base.Vial app: Hawat application to be modified.
     :return: Modified Hawat application
-    :rtype: hawat.base.VialApp
+    :rtype: hawat.base.Vial
     """
     dbcfg = hawat.db.db_settings(app)
     app.config['SQLALCHEMY_DATABASE_URI'] = dbcfg['url']
@@ -629,9 +629,9 @@ def _setup_app_eventdb(app):
     """
     Setup application database service for given Hawat application.
 
-    :param hawat.base.VialApp app: Hawat application to be modified.
+    :param hawat.base.Vial app: Hawat application to be modified.
     :return: Modified Hawat application
-    :rtype: hawat.base.VialApp
+    :rtype: hawat.base.Vial
     """
     hawat.events.db_init(app)
     app.logger.info("Connected to event database")
@@ -643,9 +643,9 @@ def _setup_app_auth(app):
     """
     Setup application authentication features.
 
-    :param hawat.base.VialApp app: Hawat application to be modified.
+    :param hawat.base.Vial app: Hawat application to be modified.
     :return: Modified Hawat application
-    :rtype: hawat.base.VialApp
+    :rtype: hawat.base.Vial
     """
 
     lim = flask_login.LoginManager()
@@ -703,9 +703,9 @@ def _setup_app_acl(app):
     """
     Setup application ACL features.
 
-    :param hawat.base.VialApp app: Hawat application to be modified.
+    :param hawat.base.Vial app: Hawat application to be modified.
     :return: Modified Hawat application
-    :rtype: hawat.base.VialApp
+    :rtype: hawat.base.Vial
     """
     fpp = flask_principal.Principal(app, skip_static = True)
     app.set_resource(hawat.const.RESOURCE_PRINCIPAL, fpp)
@@ -807,9 +807,9 @@ def _setup_app_intl(app):
     """
     Setup application`s internationalization sybsystem.
 
-    :param hawat.base.VialApp app: Hawat application to be modified.
+    :param hawat.base.Vial app: Hawat application to be modified.
     :return: Modified Hawat application
-    :rtype: hawat.base.VialApp
+    :rtype: hawat.base.Vial
     """
     app.config["BABEL_TRANSLATION_DIRECTORIES"] = "translations;"
     app.config["BABEL_TRANSLATION_DIRECTORIES"] += os.path.join(app.config["MENTAT_CORE"]["__core__reporter"]["templates_dir"], "translations;")
@@ -895,9 +895,9 @@ def _setup_app_menu(app):
     """
     Setup default application menu skeleton.
 
-    :param hawat.base.VialApp app: Hawat application to be modified.
+    :param hawat.base.Vial app: Hawat application to be modified.
     :return: Modified Hawat application
-    :rtype: hawat.base.VialApp
+    :rtype: hawat.base.Vial
     """
     for entry in app.config[hawat.const.CFGKEY_HAWAT_MENU_SKELETON]:
         app.menu_main.add_entry(**entry)
@@ -909,9 +909,9 @@ def _setup_app_blueprints(app):
     """
     Setup application blueprints.
 
-    :param hawat.base.VialApp app: Hawat application to be modified.
+    :param hawat.base.Vial app: Hawat application to be modified.
     :return: Modified Hawat application
-    :rtype: hawat.base.VialApp
+    :rtype: hawat.base.Vial
     """
     app.register_blueprints()
 
diff --git a/lib/hawat/blueprints/auth_pwd/__init__.py b/lib/hawat/blueprints/auth_pwd/__init__.py
index 2d28ea2b6e071f3ab4e75352ca6f87fd855264d4..f9aa20a159c7ec36cb6c36c7a53b3a5676b48a5c 100644
--- a/lib/hawat/blueprints/auth_pwd/__init__.py
+++ b/lib/hawat/blueprints/auth_pwd/__init__.py
@@ -50,7 +50,7 @@ from flask_babel import gettext, lazy_gettext
 from mentat.datatype.sqldb import UserModel
 import hawat.const
 import hawat.forms
-from hawat.base import HTMLMixin, SQLAlchemyMixin, SimpleView, VialAppBlueprint
+from hawat.base import HTMLMixin, SQLAlchemyMixin, SimpleView, VialBlueprint
 from hawat.blueprints.auth_pwd.forms import LoginForm
 
 
@@ -207,25 +207,25 @@ class LoginView(HTMLMixin, SQLAlchemyMixin, SimpleView):
 #-------------------------------------------------------------------------------
 
 
-class PwdAuthBlueprint(VialAppBlueprint):
+class PwdAuthBlueprint(VialBlueprint):
     """
     Pluggable module - classical password authentication (*auth_pwd*).
     """
 
     @classmethod
     def get_module_title(cls):
-        """*Implementation* of :py:func:`hawat.base.VialAppBlueprint.get_module_title`."""
+        """*Implementation* of :py:func:`hawat.base.VialBlueprint.get_module_title`."""
         return gettext('Password authentication service')
 
     def register_app(self, app):
         """
-        *Callback method*. Will be called from :py:func:`hawat.base.VialApp.register_blueprint`
+        *Callback method*. Will be called from :py:func:`hawat.base.Vial.register_blueprint`
         method and can be used to customize the Flask application object. Possible
         use cases:
 
         * application menu customization
 
-        :param hawat.base.VialApp app: Flask application to be customized.
+        :param hawat.base.Vial app: Flask application to be customized.
         """
         app.menu_anon.add_entry(
             'view',
diff --git a/lib/hawat/base.py b/lib/hawat/base.py
index 71f516d4088473d66ada43f40f26ad686d6dca4c..923b6c16bdc07810ad3bc2e2b7103cfd97ede3e1 100644
--- a/lib/hawat/base.py
+++ b/lib/hawat/base.py
@@ -20,8 +20,8 @@ scope of bare Flask microframework.
 Module contents
 ---------------
 
-* :py:class:`VialApp`
-* :py:class:`VialAppBlueprint`
+* :py:class:`Vial`
+* :py:class:`VialBlueprint`
 * :py:class:`HTMLMixin`
 * :py:class:`AJAXMixin`
 
@@ -93,9 +93,9 @@ from mentat.datatype.sqldb import ItemChangeLogModel
 CRE_QNAME = re.compile(r'^([\d]+)_([a-z]{6})$')
 RE_UQUERY = ' AS "_mentatq\\({:d}_[^)]+\\)_"'
 
-class VialAppException(Exception):
+class VialException(Exception):
     """
-    Custom class for :py:class:`hawat.base.VialApp` application exceptions.
+    Custom class for :py:class:`hawat.base.Vial` application exceptions.
     """
 
 
@@ -172,7 +172,7 @@ class URLParamsBuilder:
         return tmp
 
 
-class VialAppUtils:
+class VialUtils:
     """
     Small utility method class to enable use of those methods both in the view
     classes and in the Jinja2 templates.
@@ -191,7 +191,7 @@ class VialAppUtils:
             return None
 
 
-class VialApp(flask.Flask):
+class Vial(flask.Flask):
     """
     Custom implementation of :py:class:`flask.Flask` class. This class extends the
     capabilities of the base class with following additional features:
@@ -200,7 +200,7 @@ class VialApp(flask.Flask):
         The application configuration file contains a directive describing list
         of requested blueprints/modules, that should be registered into the
         application. This enables administrator to very easily fine tune the
-        application setup for each installation. See the :py:func:`hawat.base.VialApp.register_blueprints`
+        application setup for each installation. See the :py:func:`hawat.base.Vial.register_blueprints`
         for more information on the topic.
 
     Application main menu management
@@ -269,12 +269,12 @@ class VialApp(flask.Flask):
               within application`s ``config`` under key :py:const:`hawat.const.CFGKEY_HAWAT_BLUEPRINTS`.
             * Call blueprint`s ``register_app`` method, if available, with ``self`` as only argument.
 
         :param hawat.base.VialAppBlueprint blueprint: Blueprint to be registered.
         :param dict options: Additional options, will be passed down to :py:func:`flask.Flask.register_blueprint`.
         """
         super().register_blueprint(blueprint, **options)
 
-        if isinstance(blueprint, VialAppBlueprint):
+        if isinstance(blueprint, VialBlueprint):
             if hasattr(blueprint, 'register_app'):
                 blueprint.register_app(self)
 
@@ -287,18 +287,18 @@ class VialApp(flask.Flask):
         from :py:const:`hawat.const.CFGKEY_ENABLED_BLUEPRINTS` configuration
         subkey, which must contain list of string names of required blueprints.
         The blueprint module must provide ``get_blueprint`` factory method, that
         must return valid instance of :py:class:`hawat.base.VialAppBlueprint`. This
         method will call the :py:func:`hawat.base.VialApp.register_blueprint` for
         each blueprint, that is being registered into the application.
 
         :raises hawat.base.VialAppException: In case the factory method ``get_blueprint`` is not provided by loaded module.
         """
         for name in self.config[hawat.const.CFGKEY_ENABLED_BLUEPRINTS]:
             mod = werkzeug.utils.import_string(name)
             if hasattr(mod, 'get_blueprint'):
                 self.register_blueprint(mod.get_blueprint())
             else:
-                raise VialAppException(
+                raise VialException(
                     "Invalid blueprint module '{}', does not provide the 'get_blueprint' factory method.".format(name)
                 )
 
@@ -343,7 +343,7 @@ class VialApp(flask.Flask):
         if not endpoint in self.view_functions:
             if quiet:
                 return None
-            raise VialAppException(
+            raise VialException(
                 "Unknown endpoint name '{}'.".format(endpoint)
             )
         try:
@@ -381,7 +381,7 @@ class VialApp(flask.Flask):
 
             return True
 
-        except VialAppException:
+        except VialException:
             return False
 
     def get_resource(self, name):
@@ -489,7 +489,7 @@ class VialApp(flask.Flask):
             mailer(**kwargs)
 
 
-class VialAppBlueprint(flask.Blueprint):
+class VialBlueprint(flask.Blueprint):
     """
     Custom implementation of :py:class:`flask.Blueprint` class. This class extends
     the capabilities of the base class with additional features:
@@ -527,10 +527,10 @@ class VialAppBlueprint(flask.Blueprint):
     def register_app(self, app):  # pylint: disable=locally-disabled,no-self-use,unused-argument
         """
         *Hook method:* Custom callback, which will be called from
-        :py:func:`hawat.base.VialApp.register_blueprint` method and which can
+        :py:func:`hawat.base.Vial.register_blueprint` method and which can
         perform additional tweaking of Hawat application object.
 
-        :param hawat.base.VialApp app: Application object.
+        :param hawat.base.Vial app: Application object.
         """
         return
 
@@ -1024,7 +1024,7 @@ class BaseView(flask.views.View):
     module_name = None
     """
     Name of the parent module (blueprint). Will be set up during the process
     of registering the view into the blueprint in :py:func:`hawat.base.VialAppBlueprint.register_view_class`.
     """
 
     authentication = False
@@ -1032,7 +1032,7 @@ class BaseView(flask.views.View):
     Similar to the ``decorators`` mechanism in Flask pluggable views, you may use
     this class variable to specify, that the view is protected by authentication.
     During the process of registering the view into the blueprint in
-    :py:func:`hawat.base.VialAppBlueprint.register_view_class` the view will be
+    :py:func:`hawat.base.VialBlueprint.register_view_class` the view will be
     automatically decorated with :py:func:`flask_login.login_required` decorator.
 
     The advantage of using this in favor of ``decorators`` is that the application
@@ -1046,7 +1046,7 @@ class BaseView(flask.views.View):
     Similar to the ``decorators`` mechanism in Flask pluggable views, you may use
     this class variable to specify, that the view is protected by authorization.
     During the process of registering the view into the blueprint in
-    :py:func:`hawat.base.VialAppBlueprint.register_view_class` the view will be
+    :py:func:`hawat.base.VialBlueprint.register_view_class` the view will be
     automatically decorated with given authorization decorators.
 
     The advantage of using this in favor of ``decorators`` is that the application
@@ -1388,7 +1388,7 @@ class RenderableView(BaseView):  # pylint: disable=locally-disabled,abstract-met
         Return Jinja2 template file that should be used for rendering the view
         content. This default implementation works only in case the view class
         was properly registered into the parent blueprint/module with
-        :py:func:`hawat.base.VialAppBlueprint.register_view_class` method.
+        :py:func:`hawat.base.VialBlueprint.register_view_class` method.
 
         :return: Jinja2 template file to use to render the view.
         :rtype: str
@@ -1457,7 +1457,7 @@ class SimpleView(RenderableView):  # pylint: disable=locally-disabled,abstract-m
         return self.generate_response()
 
 
-class BaseSearchView(RenderableView, VialAppUtils):
+class BaseSearchView(RenderableView, VialUtils):
     """
     Base class for search views.
     """
@@ -2060,7 +2060,7 @@ class ItemCreateView(ItemActionView):  # pylint: disable=locally-disabled,abstra
         Return Jinja2 template file that should be used for rendering the view
         content. This default implementation works only in case the view class
         was properly registered into the parent blueprint/module with
-        :py:func:`hawat.base.VialAppBlueprint.register_view_class` method.
+        :py:func:`hawat.base.VialBlueprint.register_view_class` method.
 
         :return: Title for the view.
         :rtype: str
@@ -2181,7 +2181,7 @@ class ItemCreateForView(ItemActionView):  # pylint: disable=locally-disabled,abs
         Return Jinja2 template file that should be used for rendering the view
         content. This default implementation works only in case the view class
         was properly registered into the parent blueprint/module with
-        :py:func:`hawat.base.VialAppBlueprint.register_view_class` method.
+        :py:func:`hawat.base.VialBlueprint.register_view_class` method.
 
         :return: Title for the view.
         :rtype: str
@@ -2316,7 +2316,7 @@ class ItemUpdateView(ItemActionView):  # pylint: disable=locally-disabled,abstra
         Return Jinja2 template file that should be used for rendering the view
         content. This default implementation works only in case the view class
         was properly registered into the parent blueprint/module with
-        :py:func:`hawat.base.VialAppBlueprint.register_view_class` method.
+        :py:func:`hawat.base.VialBlueprint.register_view_class` method.
 
         :return: Title for the view.
         :rtype: str
@@ -2713,7 +2713,7 @@ class ItemObjectRelationView(ItemChangeView):  # pylint: disable=locally-disable
         Return Jinja2 template file that should be used for rendering the view
         content. This default implementation works only in case the view class
         was properly registered into the parent blueprint/module with
-        :py:func:`hawat.base.VialAppBlueprint.register_view_class` method.
+        :py:func:`hawat.base.VialBlueprint.register_view_class` method.
 
         :return: Title for the view.
         :rtype: str
@@ -269,12 +269,12 @@ class VialApp(flask.Flask):
             * Call blueprint`s ``register_app`` method, if available, with ``self`` as only argument.
 
-        :param hawat.base.VialAppBlueprint blueprint: Blueprint to be registered.
+        :param hawat.base.VialBlueprint blueprint: Blueprint to be registered.
         :param dict options: Additional options, will be passed down to :py:func:`flask.Flask.register_blueprint`.
         """
@@ -287,18 +287,18 @@ class VialApp(flask.Flask):
         subkey, which must contain list of string names of required blueprints.
         The blueprint module must provide ``get_blueprint`` factory method, that
-        must return valid instance of :py:class:`hawat.base.VialAppBlueprint`. This
-        method will call the :py:func:`hawat.base.VialApp.register_blueprint` for
+        must return valid instance of :py:class:`hawat.base.VialBlueprint`. This
+        method will call the :py:func:`hawat.base.Vial.register_blueprint` for
         each blueprint, that is being registered into the application.
 
@@ -287,18 +287,18 @@ class VialApp(flask.Flask):
         each blueprint, that is being registered into the application.
 
-        :raises hawat.base.VialAppException: In case the factory method ``get_blueprint`` is not provided by loaded module.
+        :raises hawat.base.VialException: In case the factory method ``get_blueprint`` is not provided by loaded module.
         """
         for name in self.config[hawat.const.CFGKEY_ENABLED_BLUEPRINTS]:
@@ -1024,7 +1024,7 @@ class BaseView(flask.views.View):
     """
     Name of the parent module (blueprint). Will be set up during the process
-    of registering the view into the blueprint in :py:func:`hawat.base.VialAppBlueprint.register_view_class`.
+    of registering the view into the blueprint in :py:func:`hawat.base.VialBlueprint.register_view_class`.
     """
 
diff --git a/lib/hawat/blueprints/auth_api/__init__.py b/lib/hawat/blueprints/auth_api/__init__.py
index b3a97cd7303e0f308acccfdbfe74bbd641ddbc1b..05456c7c2848b1d0e3a4f9c0fb3d9533d7dde4a0 100644
--- a/lib/hawat/blueprints/auth_api/__init__.py
+++ b/lib/hawat/blueprints/auth_api/__init__.py
@@ -75,7 +75,7 @@ from mentat.datatype.sqldb import UserModel
 import hawat.const
 import hawat.db
 import hawat.forms
-from hawat.base import HTMLMixin, SQLAlchemyMixin, ItemChangeView, VialAppBlueprint
+from hawat.base import HTMLMixin, SQLAlchemyMixin, ItemChangeView, VialBlueprint
 
 
 BLUEPRINT_NAME = 'auth_api'
@@ -231,25 +231,25 @@ class DeleteKeyView(HTMLMixin, SQLAlchemyMixin, ItemChangeView):  # pylint: disa
 #-------------------------------------------------------------------------------
 
 
-class APIAuthBlueprint(VialAppBlueprint):
+class APIAuthBlueprint(VialBlueprint):
     """
     Hawat pluggable module - API key based authentication (*auth_api*).
     """
 
     @classmethod
     def get_module_title(cls):
-        """*Implementation* of :py:func:`hawat.base.VialAppBlueprint.get_module_title`."""
+        """*Implementation* of :py:func:`hawat.base.VialBlueprint.get_module_title`."""
         return gettext('API key authentication service')
 
     def register_app(self, app):
         """
-        *Callback method*. Will be called from :py:func:`hawat.base.VialApp.register_blueprint`
+        *Callback method*. Will be called from :py:func:`hawat.base.Vial.register_blueprint`
         method and can be used to customize the Flask application object. Possible
         use cases:
 
         * application menu customization
 
-        :param hawat.base.VialApp app: Flask application to be customized.
+        :param hawat.base.Vial app: Flask application to be customized.
         """
         login_manager = app.get_resource(hawat.const.RESOURCE_LOGIN_MANAGER)
         principal = app.get_resource(hawat.const.RESOURCE_PRINCIPAL)
@@ -326,7 +326,7 @@ class APIAuthBlueprint(VialAppBlueprint):
 def get_blueprint():
     """
     Mandatory interface and factory function. This function must return a valid
     instance of :py:class:`hawat.base.VialAppBlueprint` or :py:class:`flask.Blueprint`.
     """
 
     hbp = APIAuthBlueprint(
@@ -326,7 +326,7 @@ class APIAuthBlueprint(VialAppBlueprint):
     """
     Mandatory interface and factory function. This function must return a valid
-    instance of :py:class:`hawat.base.VialAppBlueprint` or :py:class:`flask.Blueprint`.
+    instance of :py:class:`hawat.base.VialBlueprint` or :py:class:`flask.Blueprint`.
     """
 
diff --git a/lib/hawat/blueprints/auth_dev/__init__.py b/lib/hawat/blueprints/auth_dev/__init__.py
index ed6fd461d8963e69fccd1df45d7e79faf9a844df..5b22170d59c4295650a9279b713b965309a1c0a9 100644
--- a/lib/hawat/blueprints/auth_dev/__init__.py
+++ b/lib/hawat/blueprints/auth_dev/__init__.py
@@ -64,7 +64,7 @@ from flask_babel import gettext, lazy_gettext, force_locale
 from mentat.datatype.sqldb import UserModel, ItemChangeLogModel
 import hawat.const
 import hawat.forms
-from hawat.base import HTMLMixin, SQLAlchemyMixin, SimpleView, RenderableView, VialAppBlueprint
+from hawat.base import HTMLMixin, SQLAlchemyMixin, SimpleView, RenderableView, VialBlueprint
 from hawat.blueprints.auth_dev.forms import LoginForm, RegisterUserAccountForm
 
 
@@ -420,25 +420,25 @@ class RegisterView(HTMLMixin, SQLAlchemyMixin, RenderableView):
 #-------------------------------------------------------------------------------
 
 
-class DevAuthBlueprint(VialAppBlueprint):
+class DevAuthBlueprint(VialBlueprint):
     """
     Hawat pluggable module - special developer authentication (*auth_dev*).
     """
 
     @classmethod
     def get_module_title(cls):
-        """*Implementation* of :py:func:`hawat.base.VialAppBlueprint.get_module_title`."""
+        """*Implementation* of :py:func:`hawat.base.VialBlueprint.get_module_title`."""
         return gettext('Developer authentication service')
 
     def register_app(self, app):
         """
-        *Callback method*. Will be called from :py:func:`hawat.base.VialApp.register_blueprint`
+        *Callback method*. Will be called from :py:func:`hawat.base.Vial.register_blueprint`
         method and can be used to customize the Flask application object. Possible
         use cases:
 
         * application menu customization
 
-        :param hawat.base.VialApp app: Flask application to be customized.
+        :param hawat.base.Vial app: Flask application to be customized.
         """
         app.menu_anon.add_entry(
             'view',
@@ -476,7 +476,7 @@ class DevAuthBlueprint(VialAppBlueprint):
 def get_blueprint():
     """
     Mandatory interface and factory function. This function must return a valid
     instance of :py:class:`hawat.base.VialAppBlueprint` or :py:class:`flask.Blueprint`.
     """
 
     hbp = DevAuthBlueprint(
@@ -476,7 +476,7 @@ class DevAuthBlueprint(VialAppBlueprint):
     """
     Mandatory interface and factory function. This function must return a valid
-    instance of :py:class:`hawat.base.VialAppBlueprint` or :py:class:`flask.Blueprint`.
+    instance of :py:class:`hawat.base.VialBlueprint` or :py:class:`flask.Blueprint`.
     """
 
diff --git a/lib/hawat/blueprints/auth_env/__init__.py b/lib/hawat/blueprints/auth_env/__init__.py
index ac826388612507c92e65ebe4e63fef5f1737d297..cd2cca4deec542167d2fb6d5862d9d35b67e5491 100644
--- a/lib/hawat/blueprints/auth_env/__init__.py
+++ b/lib/hawat/blueprints/auth_env/__init__.py
@@ -99,7 +99,7 @@ from mentat.datatype.sqldb import UserModel, ItemChangeLogModel
 import hawat.const
 import hawat.db
 import hawat.forms
-from hawat.base import HTMLMixin, SQLAlchemyMixin, RenderableView, VialAppBlueprint
+from hawat.base import HTMLMixin, SQLAlchemyMixin, RenderableView, VialBlueprint
 from hawat.blueprints.auth_env.forms import RegisterUserAccountForm
 
 
@@ -539,25 +539,25 @@ class RegisterView(HTMLMixin, SQLAlchemyMixin, RenderableView):
 #-------------------------------------------------------------------------------
 
 
-class EnvAuthBlueprint(VialAppBlueprint):
+class EnvAuthBlueprint(VialBlueprint):
     """
     Hawat pluggable module - environment based authentication (*auth_env*).
     """
 
     @classmethod
     def get_module_title(cls):
-        """*Implementation* of :py:func:`hawat.base.VialAppBlueprint.get_module_title`."""
+        """*Implementation* of :py:func:`hawat.base.VialBlueprint.get_module_title`."""
         return gettext('Environment authentication service')
 
     def register_app(self, app):
         """
-        *Callback method*. Will be called from :py:func:`hawat.base.VialApp.register_blueprint`
+        *Callback method*. Will be called from :py:func:`hawat.base.Vial.register_blueprint`
         method and can be used to customize the Flask application object. Possible
         use cases:
 
         * application menu customization
 
-        :param hawat.base.VialApp app: Flask application to be customized.
+        :param hawat.base.Vial app: Flask application to be customized.
         """
         app.menu_anon.add_entry(
             'view',
@@ -585,7 +585,7 @@ class EnvAuthBlueprint(VialAppBlueprint):
 def get_blueprint():
     """
     Mandatory interface and factory function. This function must return a valid
     instance of :py:class:`hawat.base.VialAppBlueprint` or :py:class:`flask.Blueprint`.
     """
 
     hbp = EnvAuthBlueprint(
@@ -585,7 +585,7 @@ class EnvAuthBlueprint(VialAppBlueprint):
     """
     Mandatory interface and factory function. This function must return a valid
-    instance of :py:class:`hawat.base.VialAppBlueprint` or :py:class:`flask.Blueprint`.
+    instance of :py:class:`hawat.base.VialBlueprint` or :py:class:`flask.Blueprint`.
     """
 
diff --git a/lib/hawat/blueprints/changelogs/__init__.py b/lib/hawat/blueprints/changelogs/__init__.py
index c9a2f6f01a4a3045d137c3634de909e14031e501..aaa04a7a6e16b45e74bf417bceccab02e7aa27a8 100644
--- a/lib/hawat/blueprints/changelogs/__init__.py
+++ b/lib/hawat/blueprints/changelogs/__init__.py
@@ -33,7 +33,7 @@ from mentat.datatype.sqldb import ItemChangeLogModel
 
 import hawat.acl
 from hawat.base import HTMLMixin, SQLAlchemyMixin, BaseSearchView,\
-    ItemShowView, VialAppBlueprint
+    ItemShowView, VialBlueprint
 from hawat.blueprints.changelogs.forms import ItemChangeLogSearchForm
 
 
@@ -204,25 +204,25 @@ class ShowView(HTMLMixin, SQLAlchemyMixin, ItemShowView):
 #-------------------------------------------------------------------------------
 
 
-class ItemChangeLogsBlueprint(VialAppBlueprint):
+class ItemChangeLogsBlueprint(VialBlueprint):
     """
     Hawat pluggable module - changelogs.
     """
 
     @classmethod
     def get_module_title(cls):
-        """*Implementation* of :py:func:`hawat.base.VialAppBlueprint.get_module_title`."""
+        """*Implementation* of :py:func:`hawat.base.VialBlueprint.get_module_title`."""
         return lazy_gettext('Item changelog record pluggable module')
 
     def register_app(self, app):
         """
-        *Callback method*. Will be called from :py:func:`hawat.base.VialApp.register_blueprint`
+        *Callback method*. Will be called from :py:func:`hawat.base.Vial.register_blueprint`
         method and can be used to customize the Flask application object. Possible
         use cases:
 
         * application menu customization
 
-        :param hawat.base.VialApp app: Flask application to be customized.
+        :param hawat.base.Vial app: Flask application to be customized.
         """
         app.menu_main.add_entry(
             'view',
@@ -238,7 +238,7 @@ class ItemChangeLogsBlueprint(VialAppBlueprint):
 def get_blueprint():
     """
     Mandatory interface and factory function. This function must return a valid
     instance of :py:class:`hawat.base.VialAppBlueprint` or :py:class:`flask.Blueprint`.
     """
 
     hbp = ItemChangeLogsBlueprint(
@@ -238,7 +238,7 @@ class ItemChangeLogsBlueprint(VialAppBlueprint):
     """
     Mandatory interface and factory function. This function must return a valid
-    instance of :py:class:`hawat.base.VialAppBlueprint` or :py:class:`flask.Blueprint`.
+    instance of :py:class:`hawat.base.VialBlueprint` or :py:class:`flask.Blueprint`.
     """
 
diff --git a/lib/hawat/blueprints/dbstatus/__init__.py b/lib/hawat/blueprints/dbstatus/__init__.py
index 8f0f835d18146684871712c505964ab45c24bd07..80c4b4a0cc6747f9618469769b43798ac823ce5b 100644
--- a/lib/hawat/blueprints/dbstatus/__init__.py
+++ b/lib/hawat/blueprints/dbstatus/__init__.py
@@ -77,7 +77,7 @@ import hawat.menu
 import hawat.acl
 import hawat.events
 from hawat.forms import ItemActionConfirmForm
-from hawat.base import RenderableView, SimpleView, PsycopgMixin, SQLAlchemyMixin, AJAXMixin, HTMLMixin, VialAppBlueprint, RE_UQUERY
+from hawat.base import RenderableView, SimpleView, PsycopgMixin, SQLAlchemyMixin, AJAXMixin, HTMLMixin, VialBlueprint, RE_UQUERY
 
 
 BLUEPRINT_NAME = 'dbstatus'
@@ -705,25 +705,25 @@ class DashboardView(HTMLMixin, SQLAlchemyMixin, SimpleView):  # pylint: disable=
 #-------------------------------------------------------------------------------
 
 
-class DatabaseStatusBlueprint(VialAppBlueprint):
+class DatabaseStatusBlueprint(VialBlueprint):
     """
     Hawat pluggable module - database status.
     """
 
     @classmethod
     def get_module_title(cls):
-        """*Implementation* of :py:func:`hawat.base.VialAppBlueprint.get_module_title`."""
+        """*Implementation* of :py:func:`hawat.base.VialBlueprint.get_module_title`."""
         return lazy_gettext('Database status overview pluggable module')
 
     def register_app(self, app):
         """
-        *Callback method*. Will be called from :py:func:`hawat.base.VialApp.register_blueprint`
+        *Callback method*. Will be called from :py:func:`hawat.base.Vial.register_blueprint`
         method and can be used to customize the Flask application object. Possible
         use cases:
 
         * application menu customization
 
-        :param hawat.base.VialApp app: Flask application to be customized.
+        :param hawat.base.Vial app: Flask application to be customized.
         """
         app.menu_main.add_entry(
             'view',
@@ -751,7 +751,7 @@ class DatabaseStatusBlueprint(VialAppBlueprint):
 def get_blueprint():
     """
     Mandatory interface and factory function. This function must return a valid
     instance of :py:class:`hawat.base.VialAppBlueprint` or :py:class:`flask.Blueprint`.
     """
 
     hbp = DatabaseStatusBlueprint(
@@ -751,7 +751,7 @@ class DatabaseStatusBlueprint(VialAppBlueprint):
     """
     Mandatory interface and factory function. This function must return a valid
-    instance of :py:class:`hawat.base.VialAppBlueprint` or :py:class:`flask.Blueprint`.
+    instance of :py:class:`hawat.base.VialBlueprint` or :py:class:`flask.Blueprint`.
     """
 
diff --git a/lib/hawat/blueprints/design/__init__.py b/lib/hawat/blueprints/design/__init__.py
index 3aaf8820da2b088966edbdc6e7d5ee378660e7c0..f48c6814381c8c7095c76e7ef74c46a720f952b1 100644
--- a/lib/hawat/blueprints/design/__init__.py
+++ b/lib/hawat/blueprints/design/__init__.py
@@ -53,14 +53,14 @@ import hawat.base
 BLUEPRINT_NAME = 'design'
 
 
-class DesignBlueprint(hawat.base.VialAppBlueprint):
+class DesignBlueprint(hawat.base.VialBlueprint):
     """
     Hawat pluggable module - application design and style.
     """
 
     @classmethod
     def get_module_title(cls):
-        """*Implementation* of :py:func:`hawat.base.VialAppBlueprint.get_module_title`."""
+        """*Implementation* of :py:func:`hawat.base.VialBlueprint.get_module_title`."""
         return lazy_gettext('Hawat default design pluggable module')
 
 #-------------------------------------------------------------------------------
@@ -69,7 +69,7 @@ class DesignBlueprint(hawat.base.VialAppBlueprint):
 def get_blueprint():
     """
     Mandatory interface and factory function. This function must return a valid
     instance of :py:class:`hawat.base.VialAppBlueprint` or :py:class:`flask.Blueprint`.
     """
 
     hbp = DesignBlueprint(
@@ -69,7 +69,7 @@ class DesignBlueprint(hawat.base.VialAppBlueprint):
     """
     Mandatory interface and factory function. This function must return a valid
-    instance of :py:class:`hawat.base.VialAppBlueprint` or :py:class:`flask.Blueprint`.
+    instance of :py:class:`hawat.base.VialBlueprint` or :py:class:`flask.Blueprint`.
     """
 
diff --git a/lib/hawat/blueprints/devtools/__init__.py b/lib/hawat/blueprints/devtools/__init__.py
index cc626ecfe133bd68aff6406a02e95356a3de5a07..4b6659ca953bf80b2b071244b396036f95ea59fe 100644
--- a/lib/hawat/blueprints/devtools/__init__.py
+++ b/lib/hawat/blueprints/devtools/__init__.py
@@ -32,7 +32,7 @@ from flask_babel import lazy_gettext
 # Custom modules.
 #
 import hawat.acl
-from hawat.base import HTMLMixin, SimpleView, VialAppBlueprint
+from hawat.base import HTMLMixin, SimpleView, VialBlueprint
 
 
 BLUEPRINT_NAME = 'devtools'
@@ -72,25 +72,25 @@ class ConfigView(HTMLMixin, SimpleView):
 #-------------------------------------------------------------------------------
 
 
-class DevtoolsBlueprint(VialAppBlueprint):
+class DevtoolsBlueprint(VialBlueprint):
     """
     Hawat pluggable module - development tools.
     """
 
     @classmethod
     def get_module_title(cls):
-        """*Implementation* of :py:func:`hawat.base.VialAppBlueprint.get_module_title`."""
+        """*Implementation* of :py:func:`hawat.base.VialBlueprint.get_module_title`."""
         return lazy_gettext('Development tools pluggable module')
 
     def register_app(self, app):
         """
-        *Callback method*. Will be called from :py:func:`hawat.base.VialApp.register_blueprint`
+        *Callback method*. Will be called from :py:func:`hawat.base.Vial.register_blueprint`
         method and can be used to customize the Flask application object. Possible
         use cases:
 
         * application menu customization
 
-        :param hawat.base.VialApp app: Flask application to be customized.
+        :param hawat.base.Vial app: Flask application to be customized.
         """
         self.developer_toolbar.init_app(app)
 
@@ -108,7 +108,7 @@ class DevtoolsBlueprint(VialAppBlueprint):
 def get_blueprint():
     """
     Mandatory interface and factory function. This function must return a valid
     instance of :py:class:`hawat.base.VialAppBlueprint` or :py:class:`flask.Blueprint`.
     """
 
     hbp = DevtoolsBlueprint(
@@ -108,7 +108,7 @@ class DevtoolsBlueprint(VialAppBlueprint):
     """
     Mandatory interface and factory function. This function must return a valid
-    instance of :py:class:`hawat.base.VialAppBlueprint` or :py:class:`flask.Blueprint`.
+    instance of :py:class:`hawat.base.VialBlueprint` or :py:class:`flask.Blueprint`.
     """
 
diff --git a/lib/hawat/blueprints/dnsr/__init__.py b/lib/hawat/blueprints/dnsr/__init__.py
index bf9da187a98014e965d45da87108dc5d95096f0b..05fc1338971aa718517685519306597830104644 100644
--- a/lib/hawat/blueprints/dnsr/__init__.py
+++ b/lib/hawat/blueprints/dnsr/__init__.py
@@ -63,7 +63,7 @@ from mentat.const import tr_
 import hawat.const
 import hawat.db
 import hawat.acl
-from hawat.base import HTMLMixin, AJAXMixin, SnippetMixin, RenderableView, VialAppBlueprint, URLParamsBuilder
+from hawat.base import HTMLMixin, AJAXMixin, SnippetMixin, RenderableView, VialBlueprint, URLParamsBuilder
 from hawat.blueprints.dnsr.forms import DnsrSearchForm
 
 
@@ -173,25 +173,25 @@ class SnippetSearchView(SnippetMixin, AbstractSearchView):  # pylint: disable=lo
 #-------------------------------------------------------------------------------
 
 
-class DnsrBlueprint(VialAppBlueprint):
+class DnsrBlueprint(VialBlueprint):
     """
     Hawat pluggable module - DNS service.
     """
 
     @classmethod
     def get_module_title(cls):
-        """*Implementation* of :py:func:`hawat.base.VialAppBlueprint.get_module_title`."""
+        """*Implementation* of :py:func:`hawat.base.VialBlueprint.get_module_title`."""
         return lazy_gettext('DNS service')
 
     def register_app(self, app):
         """
-        *Callback method*. Will be called from :py:func:`hawat.base.VialApp.register_blueprint`
+        *Callback method*. Will be called from :py:func:`hawat.base.Vial.register_blueprint`
         method and can be used to customize the Flask application object. Possible
         use cases:
 
         * application menu customization
 
-        :param hawat.base.VialApp app: Flask application to be customized.
+        :param hawat.base.Vial app: Flask application to be customized.
         """
 
         mentat.services.dnsr.init(app.mconfig)
@@ -231,7 +231,7 @@ class DnsrBlueprint(VialAppBlueprint):
 def get_blueprint():
     """
     Mandatory interface and factory function. This function must return a valid
     instance of :py:class:`hawat.base.VialAppBlueprint` or :py:class:`flask.Blueprint`.
     """
 
     hbp = DnsrBlueprint(
@@ -231,7 +231,7 @@ class DnsrBlueprint(VialAppBlueprint):
     """
     Mandatory interface and factory function. This function must return a valid
-    instance of :py:class:`hawat.base.VialAppBlueprint` or :py:class:`flask.Blueprint`.
+    instance of :py:class:`hawat.base.VialBlueprint` or :py:class:`flask.Blueprint`.
     """
 
diff --git a/lib/hawat/blueprints/events/__init__.py b/lib/hawat/blueprints/events/__init__.py
index 23018662a29d887aa2527da36e776e08ff72317d..718a19ca8b7c0ece4603a0346feadb1440f010cd 100644
--- a/lib/hawat/blueprints/events/__init__.py
+++ b/lib/hawat/blueprints/events/__init__.py
@@ -39,7 +39,7 @@ import hawat.const
 import hawat.events
 import hawat.acl
 from hawat.base import HTMLMixin, PsycopgMixin, AJAXMixin, SQLAlchemyMixin,\
     BaseView, BaseSearchView, ItemShowView, SimpleView, VialAppBlueprint,\
     URLParamsBuilder
 from hawat.blueprints.events.forms import SimpleEventSearchForm, EventDashboardForm
 
@@ -468,25 +468,25 @@ class APIMetadataView(AJAXMixin, SimpleView):
 #-------------------------------------------------------------------------------
 
 
-class EventsBlueprint(VialAppBlueprint):
+class EventsBlueprint(VialBlueprint):
     """
     Hawat pluggable module - `IDEA <https://idea.cesnet.cz/en/index>`__ event database (*events*).
     """
 
     @classmethod
     def get_module_title(cls):
-        """*Implementation* of :py:func:`hawat.base.VialAppBlueprint.get_module_title`."""
+        """*Implementation* of :py:func:`hawat.base.VialBlueprint.get_module_title`."""
         return lazy_gettext('Event database')
 
     def register_app(self, app):
         """
-        *Callback method*. Will be called from :py:func:`hawat.base.VialApp.register_blueprint`
+        *Callback method*. Will be called from :py:func:`hawat.base.Vial.register_blueprint`
         method and can be used to customize the Flask application object. Possible
         use cases:
 
         * application menu customization
 
-        :param hawat.base.VialApp app: Flask application to be customized.
+        :param hawat.base.Vial app: Flask application to be customized.
         """
         app.menu_main.add_entry(
             'view',
@@ -625,7 +625,7 @@ class EventsBlueprint(VialAppBlueprint):
 def get_blueprint():
     """
     Mandatory interface and factory function. This function must return a valid
     instance of :py:class:`hawat.base.VialAppBlueprint` or :py:class:`flask.Blueprint`.
     """
 
     hbp = EventsBlueprint(
@@ -39,7 +39,7 @@ import hawat.const
 import hawat.acl
 from hawat.base import HTMLMixin, PsycopgMixin, AJAXMixin, SQLAlchemyMixin,\
-    BaseView, BaseSearchView, ItemShowView, SimpleView, VialAppBlueprint,\
+    BaseView, BaseSearchView, ItemShowView, SimpleView, VialBlueprint,\
     URLParamsBuilder
 from hawat.blueprints.events.forms import SimpleEventSearchForm, EventDashboardForm
@@ -625,7 +625,7 @@ class EventsBlueprint(VialAppBlueprint):
     """
     Mandatory interface and factory function. This function must return a valid
-    instance of :py:class:`hawat.base.VialAppBlueprint` or :py:class:`flask.Blueprint`.
+    instance of :py:class:`hawat.base.VialBlueprint` or :py:class:`flask.Blueprint`.
     """
 
diff --git a/lib/hawat/blueprints/filters/__init__.py b/lib/hawat/blueprints/filters/__init__.py
index 185a84cb5805ec8266633c79df4d07777ace3075..cd4134b0e1eab2f441455001f079108151128879 100644
--- a/lib/hawat/blueprints/filters/__init__.py
+++ b/lib/hawat/blueprints/filters/__init__.py
@@ -57,7 +57,7 @@ import hawat.db
 import hawat.events
 from hawat.base import HTMLMixin, SQLAlchemyMixin, ItemListView,\
     ItemShowView, ItemCreateView, ItemCreateForView, ItemUpdateView,\
     ItemEnableView, ItemDisableView, ItemDeleteView, RenderableView, VialAppBlueprint
 from hawat.blueprints.filters.forms import BaseFilterForm, AdminFilterForm, PlaygroundFilterForm
 
 
@@ -846,25 +846,25 @@ class PlaygroundView(HTMLMixin, RenderableView):
 #-------------------------------------------------------------------------------
 
 
-class FiltersBlueprint(VialAppBlueprint):
+class FiltersBlueprint(VialBlueprint):
     """
     Hawat pluggable module - reporting filters.
     """
 
     @classmethod
     def get_module_title(cls):
-        """*Implementation* of :py:func:`hawat.base.VialAppBlueprint.get_module_title`."""
+        """*Implementation* of :py:func:`hawat.base.VialBlueprint.get_module_title`."""
         return lazy_gettext('Reporting filter management pluggable module')
 
     def register_app(self, app):
         """
-        *Callback method*. Will be called from :py:func:`hawat.base.VialApp.register_blueprint`
+        *Callback method*. Will be called from :py:func:`hawat.base.Vial.register_blueprint`
         method and can be used to customize the Flask application object. Possible
         use cases:
 
         * application menu customization
 
-        :param hawat.base.VialApp app: Flask application to be customized.
+        :param hawat.base.Vial app: Flask application to be customized.
         """
         app.menu_main.add_entry(
             'view',
@@ -887,7 +887,7 @@ class FiltersBlueprint(VialAppBlueprint):
 def get_blueprint():
     """
     Mandatory interface and factory function. This function must return a valid
     instance of :py:class:`hawat.base.VialAppBlueprint` or :py:class:`flask.Blueprint`.
     """
 
     hbp = FiltersBlueprint(
@@ -57,7 +57,7 @@ import hawat.db
 from hawat.base import HTMLMixin, SQLAlchemyMixin, ItemListView,\
     ItemShowView, ItemCreateView, ItemCreateForView, ItemUpdateView,\
-    ItemEnableView, ItemDisableView, ItemDeleteView, RenderableView, VialAppBlueprint
+    ItemEnableView, ItemDisableView, ItemDeleteView, RenderableView, VialBlueprint
 from hawat.blueprints.filters.forms import BaseFilterForm, AdminFilterForm, PlaygroundFilterForm
 
@@ -887,7 +887,7 @@ class FiltersBlueprint(VialAppBlueprint):
     """
     Mandatory interface and factory function. This function must return a valid
-    instance of :py:class:`hawat.base.VialAppBlueprint` or :py:class:`flask.Blueprint`.
+    instance of :py:class:`hawat.base.VialBlueprint` or :py:class:`flask.Blueprint`.
     """
 
diff --git a/lib/hawat/blueprints/geoip/__init__.py b/lib/hawat/blueprints/geoip/__init__.py
index a5a40f9c8115f118ba3640cb8160e93a6ecbcf34..b2733641a9498b66fe15382c903de05e4693c5f1 100644
--- a/lib/hawat/blueprints/geoip/__init__.py
+++ b/lib/hawat/blueprints/geoip/__init__.py
@@ -66,7 +66,7 @@ from mentat.const import tr_
 import hawat.const
 import hawat.db
 import hawat.acl
-from hawat.base import HTMLMixin, AJAXMixin, SnippetMixin, RenderableView, VialAppBlueprint, URLParamsBuilder
+from hawat.base import HTMLMixin, AJAXMixin, SnippetMixin, RenderableView, VialBlueprint, URLParamsBuilder
 from hawat.blueprints.geoip.forms import GeoipSearchForm
 
 
@@ -181,25 +181,25 @@ class SnippetSearchView(SnippetMixin, AbstractSearchView):  # pylint: disable=lo
 #-------------------------------------------------------------------------------
 
 
-class GeoipBlueprint(VialAppBlueprint):
+class GeoipBlueprint(VialBlueprint):
     """
     Hawat pluggable module - IP geolocation service.
     """
 
     @classmethod
     def get_module_title(cls):
-        """*Implementation* of :py:func:`hawat.base.VialAppBlueprint.get_module_title`."""
+        """*Implementation* of :py:func:`hawat.base.VialBlueprint.get_module_title`."""
         return lazy_gettext('IP geolocation service')
 
     def register_app(self, app):
         """
-        *Callback method*. Will be called from :py:func:`hawat.base.VialApp.register_blueprint`
+        *Callback method*. Will be called from :py:func:`hawat.base.Vial.register_blueprint`
         method and can be used to customize the Flask application object. Possible
         use cases:
 
         * application menu customization
 
-        :param hawat.base.VialApp app: Flask application to be customized.
+        :param hawat.base.Vial app: Flask application to be customized.
         """
         mentat.services.geoip.init(app.mconfig)
 
@@ -237,7 +237,7 @@ class GeoipBlueprint(VialAppBlueprint):
 def get_blueprint():
     """
     Mandatory interface and factory function. This function must return a valid
     instance of :py:class:`hawat.base.VialAppBlueprint` or :py:class:`flask.Blueprint`.
     """
 
     hbp = GeoipBlueprint(
@@ -237,7 +237,7 @@ class GeoipBlueprint(VialAppBlueprint):
     """
     Mandatory interface and factory function. This function must return a valid
-    instance of :py:class:`hawat.base.VialAppBlueprint` or :py:class:`flask.Blueprint`.
+    instance of :py:class:`hawat.base.VialBlueprint` or :py:class:`flask.Blueprint`.
     """
 
diff --git a/lib/hawat/blueprints/groups/__init__.py b/lib/hawat/blueprints/groups/__init__.py
index 21c79cfe0def639ba6b14b83d0a3e89768abce87..7bbc1d5484d462b5294c4b3f27bd85f6644d38ba 100644
--- a/lib/hawat/blueprints/groups/__init__.py
+++ b/lib/hawat/blueprints/groups/__init__.py
@@ -50,7 +50,7 @@ import hawat.db
 import hawat.menu
 from hawat.base import HTMLMixin, SQLAlchemyMixin, ItemListView,\
     ItemShowView, ItemCreateView, ItemUpdateView, ItemEnableView,\
-    ItemDisableView, ItemObjectRelationView, ItemDeleteView, VialAppBlueprint,\
+    ItemDisableView, ItemObjectRelationView, ItemDeleteView, VialBlueprint,\
     URLParamsBuilder
 
 from hawat.blueprints.groups.forms import AdminCreateGroupForm, AdminUpdateGroupForm,\
@@ -925,25 +925,25 @@ class DeleteView(HTMLMixin, SQLAlchemyMixin, ItemDeleteView):  # pylint: disable
 #-------------------------------------------------------------------------------
 
 
-class GroupsBlueprint(VialAppBlueprint):
+class GroupsBlueprint(VialBlueprint):
     """
     Hawat pluggable module - abuse groups.
     """
 
     @classmethod
     def get_module_title(cls):
-        """*Implementation* of :py:func:`hawat.base.VialAppBlueprint.get_module_title`."""
+        """*Implementation* of :py:func:`hawat.base.VialBlueprint.get_module_title`."""
         return lazy_gettext('Group management pluggable module')
 
     def register_app(self, app):
         """
-        *Callback method*. Will be called from :py:func:`hawat.base.VialApp.register_blueprint`
+        *Callback method*. Will be called from :py:func:`hawat.base.Vial.register_blueprint`
         method and can be used to customize the Flask application object. Possible
         use cases:
 
         * application menu customization
 
-        :param hawat.base.VialApp app: Flask application to be customized.
+        :param hawat.base.Vial app: Flask application to be customized.
         """
 
         def _fetch_my_groups():
@@ -985,7 +985,7 @@ class GroupsBlueprint(VialAppBlueprint):
 def get_blueprint():
     """
     Mandatory interface and factory function. This function must return a valid
     instance of :py:class:`hawat.base.VialAppBlueprint` or :py:class:`flask.Blueprint`.
     """
 
     hbp = GroupsBlueprint(
@@ -985,7 +985,7 @@ class GroupsBlueprint(VialAppBlueprint):
     """
     Mandatory interface and factory function. This function must return a valid
-    instance of :py:class:`hawat.base.VialAppBlueprint` or :py:class:`flask.Blueprint`.
+    instance of :py:class:`hawat.base.VialBlueprint` or :py:class:`flask.Blueprint`.
     """
 
diff --git a/lib/hawat/blueprints/home/__init__.py b/lib/hawat/blueprints/home/__init__.py
index 9b0464662ccc666d9d66843f4700dfa16dcf019b..f0ad33f2460623fe8cafdd91f3a0fe7ab665d996 100644
--- a/lib/hawat/blueprints/home/__init__.py
+++ b/lib/hawat/blueprints/home/__init__.py
@@ -38,7 +38,7 @@ from flask_babel import lazy_gettext
 #
 # Custom modules.
 #
-from hawat.base import HTMLMixin, SimpleView, VialAppBlueprint
+from hawat.base import HTMLMixin, SimpleView, VialBlueprint
 
 
 BLUEPRINT_NAME = 'home'
@@ -75,14 +75,14 @@ class IndexView(HTMLMixin, SimpleView):
 #-------------------------------------------------------------------------------
 
 
-class HomeBlueprint(VialAppBlueprint):
+class HomeBlueprint(VialBlueprint):
     """
     Pluggable module - home page (*home*).
     """
 
     @classmethod
     def get_module_title(cls):
-        """*Implementation* of :py:func:`hawat.base.VialAppBlueprint.get_module_title`."""
+        """*Implementation* of :py:func:`hawat.base.VialBlueprint.get_module_title`."""
         return lazy_gettext('Home page pluggable module')
 
 
@@ -92,7 +92,7 @@ class HomeBlueprint(VialAppBlueprint):
 def get_blueprint():
     """
     Mandatory interface and factory function. This function must return a valid
     instance of :py:class:`hawat.base.VialAppBlueprint` or :py:class:`flask.Blueprint`.
     """
 
     hbp = HomeBlueprint(
@@ -92,7 +92,7 @@ class HomeBlueprint(VialAppBlueprint):
     """
     Mandatory interface and factory function. This function must return a valid
-    instance of :py:class:`hawat.base.VialAppBlueprint` or :py:class:`flask.Blueprint`.
+    instance of :py:class:`hawat.base.VialBlueprint` or :py:class:`flask.Blueprint`.
     """
 
diff --git a/lib/hawat/blueprints/hosts/__init__.py b/lib/hawat/blueprints/hosts/__init__.py
index 6a9643139224667dad6d5b3f5fba3b3d8193ef33..aeed2af526057fc48a6e48e6b03693a4b089d043 100644
--- a/lib/hawat/blueprints/hosts/__init__.py
+++ b/lib/hawat/blueprints/hosts/__init__.py
@@ -40,7 +40,7 @@ import hawat.const
 import hawat.events
 import hawat.acl
 from hawat.base import HTMLMixin, PsycopgMixin, AJAXMixin,\
-    BaseSearchView, VialAppBlueprint, URLParamsBuilder
+    BaseSearchView, VialBlueprint, URLParamsBuilder
 from hawat.blueprints.hosts.forms import SimpleHostSearchForm
 
 
@@ -171,25 +171,25 @@ class APISearchView(AJAXMixin, AbstractSearchView):  # pylint: disable=locally-d
 #-------------------------------------------------------------------------------
 
 
-class HostsBlueprint(VialAppBlueprint):
+class HostsBlueprint(VialBlueprint):
     """
     Hawat pluggable module - Host overview.
     """
 
     @classmethod
     def get_module_title(cls):
-        """*Implementation* of :py:func:`hawat.base.VialAppBlueprint.get_module_title`."""
+        """*Implementation* of :py:func:`hawat.base.VialBlueprint.get_module_title`."""
         return lazy_gettext('Host overview pluggable module')
 
     def register_app(self, app):
         """
-        *Callback method*. Will be called from :py:func:`hawat.base.VialApp.register_blueprint`
+        *Callback method*. Will be called from :py:func:`hawat.base.Vial.register_blueprint`
         method and can be used to customize the Flask application object. Possible
         use cases:
 
         * application menu customization
 
-        :param hawat.base.VialApp app: Flask application to be customized.
+        :param hawat.base.Vial app: Flask application to be customized.
         """
         app.menu_main.add_entry(
             'view',
@@ -213,7 +213,7 @@ class HostsBlueprint(VialAppBlueprint):
 def get_blueprint():
     """
     Mandatory interface and factory function. This function must return a valid
     instance of :py:class:`hawat.base.VialAppBlueprint` or :py:class:`flask.Blueprint`.
     """
 
     hbp = HostsBlueprint(
@@ -213,7 +213,7 @@ class HostsBlueprint(VialAppBlueprint):
     """
     Mandatory interface and factory function. This function must return a valid
-    instance of :py:class:`hawat.base.VialAppBlueprint` or :py:class:`flask.Blueprint`.
+    instance of :py:class:`hawat.base.VialBlueprint` or :py:class:`flask.Blueprint`.
     """
 
diff --git a/lib/hawat/blueprints/nerd/__init__.py b/lib/hawat/blueprints/nerd/__init__.py
index a0e203e3cc1974dd4679bd7b190d9d5823228e2f..f6e5fa7e06239eae13c02bc1414bd7553f4a71f8 100644
--- a/lib/hawat/blueprints/nerd/__init__.py
+++ b/lib/hawat/blueprints/nerd/__init__.py
@@ -64,7 +64,7 @@ from mentat.const import tr_
 import hawat.const
 import hawat.db
 import hawat.acl
-from hawat.base import HTMLMixin, AJAXMixin, SnippetMixin, RenderableView, VialAppBlueprint, URLParamsBuilder
+from hawat.base import HTMLMixin, AJAXMixin, SnippetMixin, RenderableView, VialBlueprint, URLParamsBuilder
 from hawat.blueprints.nerd.forms import NerdSearchForm
 
 
@@ -173,25 +173,25 @@ class SnippetSearchView(SnippetMixin, AbstractSearchView):  # pylint: disable=lo
 #-------------------------------------------------------------------------------
 
 
-class NerdBlueprint(VialAppBlueprint):
+class NerdBlueprint(VialBlueprint):
     """
     Hawat pluggable module - NERD service.
     """
 
     @classmethod
     def get_module_title(cls):
-        """*Implementation* of :py:func:`hawat.base.VialAppBlueprint.get_module_title`."""
+        """*Implementation* of :py:func:`hawat.base.VialBlueprint.get_module_title`."""
         return lazy_gettext('NERD service')
 
     def register_app(self, app):
         """
-        *Callback method*. Will be called from :py:func:`hawat.base.VialApp.register_blueprint`
+        *Callback method*. Will be called from :py:func:`hawat.base.Vial.register_blueprint`
         method and can be used to customize the Flask application object. Possible
         use cases:
 
         * application menu customization
 
-        :param hawat.base.VialApp app: Flask application to be customized.
+        :param hawat.base.Vial app: Flask application to be customized.
         """
 
         mentat.services.nerd.init(app.mconfig)
@@ -231,7 +231,7 @@ class NerdBlueprint(VialAppBlueprint):
 def get_blueprint():
     """
     Mandatory interface and factory function. This function must return a valid
     instance of :py:class:`hawat.base.VialAppBlueprint` or :py:class:`flask.Blueprint`.
     """
 
     hbp = NerdBlueprint(
@@ -231,7 +231,7 @@ class NerdBlueprint(VialAppBlueprint):
     """
     Mandatory interface and factory function. This function must return a valid
-    instance of :py:class:`hawat.base.VialAppBlueprint` or :py:class:`flask.Blueprint`.
+    instance of :py:class:`hawat.base.VialBlueprint` or :py:class:`flask.Blueprint`.
     """
 
diff --git a/lib/hawat/blueprints/networks/__init__.py b/lib/hawat/blueprints/networks/__init__.py
index a32b8c33373d4c9c0235c457f185eb1fe5282386..29c07acedc89e3f10a0d13540026a92ac90847b6 100644
--- a/lib/hawat/blueprints/networks/__init__.py
+++ b/lib/hawat/blueprints/networks/__init__.py
@@ -44,7 +44,7 @@ import hawat.base
 import hawat.db
 from hawat.base import HTMLMixin, SQLAlchemyMixin, ItemListView,\
     ItemShowView, ItemCreateView, ItemCreateForView, ItemUpdateView,\
-    ItemDeleteView, VialAppBlueprint
+    ItemDeleteView, VialBlueprint
 from hawat.blueprints.networks.forms import BaseNetworkForm, AdminNetworkForm
 
 
@@ -443,25 +443,25 @@ class DeleteView(HTMLMixin, SQLAlchemyMixin, ItemDeleteView):  # pylint: disable
 #-------------------------------------------------------------------------------
 
 
-class NetworksBlueprint(VialAppBlueprint):
+class NetworksBlueprint(VialBlueprint):
     """
     Hawat pluggable module - networks.
     """
 
     @classmethod
     def get_module_title(cls):
-        """*Implementation* of :py:func:`hawat.base.VialAppBlueprint.get_module_title`."""
+        """*Implementation* of :py:func:`hawat.base.VialBlueprint.get_module_title`."""
         return lazy_gettext('Network record management pluggable module')
 
     def register_app(self, app):
         """
-        *Callback method*. Will be called from :py:func:`hawat.base.VialApp.register_blueprint`
+        *Callback method*. Will be called from :py:func:`hawat.base.Vial.register_blueprint`
         method and can be used to customize the Flask application object. Possible
         use cases:
 
         * application menu customization
 
-        :param hawat.base.VialApp app: Flask application to be customized.
+        :param hawat.base.Vial app: Flask application to be customized.
         """
         app.menu_main.add_entry(
             'view',
@@ -477,7 +477,7 @@ class NetworksBlueprint(VialAppBlueprint):
 def get_blueprint():
     """
     Mandatory interface and factory function. This function must return a valid
     instance of :py:class:`hawat.base.VialAppBlueprint` or :py:class:`flask.Blueprint`.
     """
 
     hbp = NetworksBlueprint(
@@ -477,7 +477,7 @@ class NetworksBlueprint(VialAppBlueprint):
     """
     Mandatory interface and factory function. This function must return a valid
-    instance of :py:class:`hawat.base.VialAppBlueprint` or :py:class:`flask.Blueprint`.
+    instance of :py:class:`hawat.base.VialBlueprint` or :py:class:`flask.Blueprint`.
     """
 
diff --git a/lib/hawat/blueprints/pdnsr/__init__.py b/lib/hawat/blueprints/pdnsr/__init__.py
index fcf46327e8eb4e3e681ac27371229f74c66da140..25cd1ba2415dccdec15765cfca27fcb185a4a422 100644
--- a/lib/hawat/blueprints/pdnsr/__init__.py
+++ b/lib/hawat/blueprints/pdnsr/__init__.py
@@ -64,7 +64,7 @@ from mentat.const import tr_
 import hawat.const
 import hawat.db
 import hawat.acl
-from hawat.base import HTMLMixin, AJAXMixin, SnippetMixin, RenderableView, VialAppBlueprint, URLParamsBuilder
+from hawat.base import HTMLMixin, AJAXMixin, SnippetMixin, RenderableView, VialBlueprint, URLParamsBuilder
 from hawat.blueprints.pdnsr.forms import PDNSRSearchForm
 
 
@@ -178,25 +178,25 @@ class SnippetSearchView(SnippetMixin, AbstractSearchView):  # pylint: disable=lo
 #-------------------------------------------------------------------------------
 
 
-class PDNSRBlueprint(VialAppBlueprint):
+class PDNSRBlueprint(VialBlueprint):
     """
     Hawat pluggable module - PassiveDNS service.
     """
 
     @classmethod
     def get_module_title(cls):
-        """*Implementation* of :py:func:`hawat.base.VialAppBlueprint.get_module_title`."""
+        """*Implementation* of :py:func:`hawat.base.VialBlueprint.get_module_title`."""
         return lazy_gettext('PassiveDNS service')
 
     def register_app(self, app):
         """
-        *Callback method*. Will be called from :py:func:`hawat.base.VialApp.register_blueprint`
+        *Callback method*. Will be called from :py:func:`hawat.base.Vial.register_blueprint`
         method and can be used to customize the Flask application object. Possible
         use cases:
 
         * application menu customization
 
-        :param hawat.base.VialApp app: Flask application to be customized.
+        :param hawat.base.Vial app: Flask application to be customized.
         """
 
         mentat.services.pdnsr.init(app.mconfig)
@@ -241,7 +241,7 @@ class PDNSRBlueprint(VialAppBlueprint):
 def get_blueprint():
     """
     Mandatory interface and factory function. This function must return a valid
     instance of :py:class:`hawat.base.VialAppBlueprint` or :py:class:`flask.Blueprint`.
     """
 
     hbp = PDNSRBlueprint(
@@ -241,7 +241,7 @@ class PDNSRBlueprint(VialAppBlueprint):
     """
     Mandatory interface and factory function. This function must return a valid
-    instance of :py:class:`hawat.base.VialAppBlueprint` or :py:class:`flask.Blueprint`.
+    instance of :py:class:`hawat.base.VialBlueprint` or :py:class:`flask.Blueprint`.
     """
 
diff --git a/lib/hawat/blueprints/performance/__init__.py b/lib/hawat/blueprints/performance/__init__.py
index 6739e05f6940ecad674143e42140a5b202cf8181..46fa5fd7d8d0994caee72dc72de7607bda7dba2a 100644
--- a/lib/hawat/blueprints/performance/__init__.py
+++ b/lib/hawat/blueprints/performance/__init__.py
@@ -26,7 +26,7 @@ from flask_babel import lazy_gettext
 
 import mentat.stats.rrd
 import hawat.acl
-from hawat.base import HTMLMixin, SimpleView, FileNameView, VialAppBlueprint
+from hawat.base import HTMLMixin, SimpleView, FileNameView, VialBlueprint
 
 RRD_DB_DIR      = '/var/mentat/rrds'
 RRD_REPORTS_DIR = '/var/mentat/reports/statistician'
@@ -141,25 +141,25 @@ class RRDDBView(FileNameView):
 #-------------------------------------------------------------------------------
 
 
-class PerformanceBlueprint(VialAppBlueprint):
+class PerformanceBlueprint(VialBlueprint):
     """
     Hawat pluggable module - system processing performance.
     """
 
     @classmethod
     def get_module_title(cls):
-        """*Implementation* of :py:func:`hawat.base.VialAppBlueprint.get_module_title`."""
+        """*Implementation* of :py:func:`hawat.base.VialBlueprint.get_module_title`."""
         return lazy_gettext('System performance pluggable module')
 
     def register_app(self, app):
         """
-        *Callback method*. Will be called from :py:func:`hawat.base.VialApp.register_blueprint`
+        *Callback method*. Will be called from :py:func:`hawat.base.Vial.register_blueprint`
         method and can be used to customize the Flask application object. Possible
         use cases:
 
         * application menu customization
 
-        :param hawat.base.VialApp app: Flask application to be customized.
+        :param hawat.base.Vial app: Flask application to be customized.
         """
         app.menu_main.add_entry(
             'view',
@@ -176,7 +176,7 @@ class PerformanceBlueprint(VialAppBlueprint):
 def get_blueprint():
     """
     Mandatory interface and factory function. This function must return a valid
     instance of :py:class:`hawat.base.VialAppBlueprint` or :py:class:`flask.Blueprint`.
     """
 
     hbp = PerformanceBlueprint(
@@ -176,7 +176,7 @@ class PerformanceBlueprint(VialAppBlueprint):
     """
     Mandatory interface and factory function. This function must return a valid
-    instance of :py:class:`hawat.base.VialAppBlueprint` or :py:class:`flask.Blueprint`.
+    instance of :py:class:`hawat.base.VialBlueprint` or :py:class:`flask.Blueprint`.
     """
 
diff --git a/lib/hawat/blueprints/reports/__init__.py b/lib/hawat/blueprints/reports/__init__.py
index c76917017c5db8d30fd887e982a6b98eb882dc02..2a0edee71d7482cb49ae03290c4f8e63cacf92ae 100644
--- a/lib/hawat/blueprints/reports/__init__.py
+++ b/lib/hawat/blueprints/reports/__init__.py
@@ -49,7 +49,7 @@ from mentat.const import tr_
 import hawat.menu
 import hawat.acl
 from hawat.base import HTMLMixin, SQLAlchemyMixin, AJAXMixin, BaseSearchView, \
-    ItemShowView, ItemDeleteView, FileIdView, VialAppBlueprint,\
+    ItemShowView, ItemDeleteView, FileIdView, VialBlueprint,\
     URLParamsBuilder, RenderableView
 from hawat.blueprints.reports.forms import EventReportSearchForm, ReportingDashboardForm, \
     FeedbackForm
@@ -635,25 +635,25 @@ class FeedbackView(AJAXMixin, RenderableView):
 #-------------------------------------------------------------------------------
 
 
-class ReportsBlueprint(VialAppBlueprint):
+class ReportsBlueprint(VialBlueprint):
     """
     Hawat pluggable module - event reports.
     """
 
     @classmethod
     def get_module_title(cls):
-        """*Implementation* of :py:func:`hawat.base.VialAppBlueprint.get_module_title`."""
+        """*Implementation* of :py:func:`hawat.base.VialBlueprint.get_module_title`."""
         return lazy_gettext('Event reports')
 
     def register_app(self, app):
         """
-        *Callback method*. Will be called from :py:func:`hawat.base.VialApp.register_blueprint`
+        *Callback method*. Will be called from :py:func:`hawat.base.Vial.register_blueprint`
         method and can be used to customize the Flask application object. Possible
         use cases:
 
         * application menu customization
 
-        :param hawat.base.VialApp app: Flask application to be customized.
+        :param hawat.base.Vial app: Flask application to be customized.
         """
         app.menu_main.add_entry(
             'view',
@@ -700,7 +700,7 @@ class ReportsBlueprint(VialAppBlueprint):
 def get_blueprint():
     """
     Mandatory interface and factory function. This function must return a valid
     instance of :py:class:`hawat.base.VialAppBlueprint` or :py:class:`flask.Blueprint`.
     """
 
     hbp = ReportsBlueprint(
@@ -700,7 +700,7 @@ class ReportsBlueprint(VialAppBlueprint):
     """
     Mandatory interface and factory function. This function must return a valid
-    instance of :py:class:`hawat.base.VialAppBlueprint` or :py:class:`flask.Blueprint`.
+    instance of :py:class:`hawat.base.VialBlueprint` or :py:class:`flask.Blueprint`.
     """
 
diff --git a/lib/hawat/blueprints/settings_reporting/__init__.py b/lib/hawat/blueprints/settings_reporting/__init__.py
index a4a022dc4c7422673612b061af7cfadcb6e17394..8fefb57bcbf8b340f9a0ac6ee01b3f342ae0bfdd 100644
--- a/lib/hawat/blueprints/settings_reporting/__init__.py
+++ b/lib/hawat/blueprints/settings_reporting/__init__.py
@@ -41,7 +41,7 @@ from mentat.datatype.sqldb import SettingsReportingModel, ItemChangeLogModel
 
 import hawat.db
 from hawat.base import HTMLMixin, SQLAlchemyMixin, ItemShowView,\
-    ItemCreateView, ItemUpdateView, VialAppBlueprint
+    ItemCreateView, ItemUpdateView, VialBlueprint
 from hawat.blueprints.settings_reporting.forms import CreateSettingsReportingForm,\
     UpdateSettingsReportingForm
 
@@ -304,14 +304,14 @@ class UpdateView(HTMLMixin, SQLAlchemyMixin, ItemUpdateView):  # pylint: disable
 #-------------------------------------------------------------------------------
 
 
-class SettingsReportingBlueprint(VialAppBlueprint):
+class SettingsReportingBlueprint(VialBlueprint):
     """
     Hawat pluggable module - reporting settings.
     """
 
     @classmethod
     def get_module_title(cls):
-        """*Implementation* of :py:func:`hawat.base.VialAppBlueprint.get_module_title`."""
+        """*Implementation* of :py:func:`hawat.base.VialBlueprint.get_module_title`."""
         return lazy_gettext('Reporting settings management pluggable module')
 
 
@@ -321,7 +321,7 @@ class SettingsReportingBlueprint(VialAppBlueprint):
 def get_blueprint():
     """
     Mandatory interface and factory function. This function must return a valid
     instance of :py:class:`hawat.base.VialAppBlueprint` or :py:class:`flask.Blueprint`.
     """
 
     hbp = SettingsReportingBlueprint(
@@ -321,7 +321,7 @@ class SettingsReportingBlueprint(VialAppBlueprint):
     """
     Mandatory interface and factory function. This function must return a valid
-    instance of :py:class:`hawat.base.VialAppBlueprint` or :py:class:`flask.Blueprint`.
+    instance of :py:class:`hawat.base.VialBlueprint` or :py:class:`flask.Blueprint`.
     """
 
diff --git a/lib/hawat/blueprints/skeleton/__init__.py b/lib/hawat/blueprints/skeleton/__init__.py
index 2e90d7bc5657c7e75e0db256dda9beeca4cc1231..c009673deb039d0a52da0f5c704f71501d78b3e3 100644
--- a/lib/hawat/blueprints/skeleton/__init__.py
+++ b/lib/hawat/blueprints/skeleton/__init__.py
@@ -70,25 +70,25 @@ class ExampleView(hawat.base.HTMLMixin, hawat.base.SimpleView):
 #-------------------------------------------------------------------------------
 
 
-class SkeletonBlueprint(hawat.base.VialAppBlueprint):
+class SkeletonBlueprint(hawat.base.VialBlueprint):
     """
     Hawat pluggable module - skeleton.
     """
 
     @classmethod
     def get_module_title(cls):
-        """*Implementation* of :py:func:`hawat.base.VialAppBlueprint.get_module_title`."""
+        """*Implementation* of :py:func:`hawat.base.VialBlueprint.get_module_title`."""
         return lazy_gettext('Skeleton module')
 
     def register_app(self, app):
         """
-        *Callback method*. Will be called from :py:func:`hawat.base.VialApp.register_blueprint`
+        *Callback method*. Will be called from :py:func:`hawat.base.Vial.register_blueprint`
         method and can be used to customize the Flask application object. Possible
         use cases:
 
         * application menu customization
 
-        :param hawat.base.VialApp app: Flask application to be customized.
+        :param hawat.base.Vial app: Flask application to be customized.
         """
         app.menu_main.add_entry(
             'view',
@@ -104,7 +104,7 @@ class SkeletonBlueprint(hawat.base.VialAppBlueprint):
 def get_blueprint():
     """
     Mandatory interface and factory function. This function must return a valid
     instance of :py:class:`hawat.base.VialAppBlueprint` or :py:class:`flask.Blueprint`.
     """
 
     hbp = SkeletonBlueprint(
@@ -104,7 +104,7 @@ class SkeletonBlueprint(hawat.base.VialAppBlueprint):
     """
     Mandatory interface and factory function. This function must return a valid
-    instance of :py:class:`hawat.base.VialAppBlueprint` or :py:class:`flask.Blueprint`.
+    instance of :py:class:`hawat.base.VialBlueprint` or :py:class:`flask.Blueprint`.
     """
 
diff --git a/lib/hawat/blueprints/status/__init__.py b/lib/hawat/blueprints/status/__init__.py
index c472e0edcd0feac703ee3ad6ef8b5bb7a01aab67..f42db6e46c83b17ad5a42122ea72469dc5a0acfe 100644
--- a/lib/hawat/blueprints/status/__init__.py
+++ b/lib/hawat/blueprints/status/__init__.py
@@ -47,7 +47,7 @@ from flask_babel import lazy_gettext
 import pyzenkit.jsonconf
 import mentat.system
 import hawat.acl
-from hawat.base import HTMLMixin, SimpleView, VialAppBlueprint
+from hawat.base import HTMLMixin, SimpleView, VialBlueprint
 
 
 BLUEPRINT_NAME = 'status'
@@ -113,25 +113,25 @@ class ViewView(HTMLMixin, SimpleView):
 #-------------------------------------------------------------------------------
 
 
-class StatusBlueprint(VialAppBlueprint):
+class StatusBlueprint(VialBlueprint):
     """
     Hawat pluggable module - Mentat system status.
     """
 
     @classmethod
     def get_module_title(cls):
-        """*Implementation* of :py:func:`hawat.base.VialAppBlueprint.get_module_title`."""
+        """*Implementation* of :py:func:`hawat.base.VialBlueprint.get_module_title`."""
         return lazy_gettext('System status pluggable module')
 
     def register_app(self, app):
         """
-        *Callback method*. Will be called from :py:func:`hawat.base.VialApp.register_blueprint`
+        *Callback method*. Will be called from :py:func:`hawat.base.Vial.register_blueprint`
         method and can be used to customize the Flask application object. Possible
         use cases:
 
         * application menu customization
 
-        :param hawat.base.VialApp app: Flask application to be customized.
+        :param hawat.base.Vial app: Flask application to be customized.
         """
         app.menu_main.add_entry(
             'view',
@@ -148,7 +148,7 @@ class StatusBlueprint(VialAppBlueprint):
 def get_blueprint():
     """
     Mandatory interface and factory function. This function must return a valid
     instance of :py:class:`hawat.base.VialAppBlueprint` or :py:class:`flask.Blueprint`.
     """
 
     hbp = StatusBlueprint(
@@ -148,7 +148,7 @@ class StatusBlueprint(VialAppBlueprint):
     """
     Mandatory interface and factory function. This function must return a valid
-    instance of :py:class:`hawat.base.VialAppBlueprint` or :py:class:`flask.Blueprint`.
+    instance of :py:class:`hawat.base.VialBlueprint` or :py:class:`flask.Blueprint`.
     """
 
diff --git a/lib/hawat/blueprints/timeline/__init__.py b/lib/hawat/blueprints/timeline/__init__.py
index 9b536c7d3eac9a5144d0ef1f43b30f5b76b2dd51..12219c057ad3d7a7304fc3b68712bc8c0b5daef8 100644
--- a/lib/hawat/blueprints/timeline/__init__.py
+++ b/lib/hawat/blueprints/timeline/__init__.py
@@ -39,7 +39,7 @@ import hawat.const
 import hawat.events
 import hawat.acl
 from hawat.base import HTMLMixin, PsycopgMixin, AJAXMixin,\
-    BaseSearchView, VialAppBlueprint, URLParamsBuilder
+    BaseSearchView, VialBlueprint, URLParamsBuilder
 from hawat.blueprints.timeline.forms import SimpleTimelineSearchForm
 
 
@@ -195,25 +195,25 @@ class APISearchView(AJAXMixin, AbstractSearchView):  # pylint: disable=locally-d
 #-------------------------------------------------------------------------------
 
 
-class TimelineBlueprint(VialAppBlueprint):
+class TimelineBlueprint(VialBlueprint):
     """
     Hawat pluggable module - IDEA event timelines.
     """
 
     @classmethod
     def get_module_title(cls):
-        """*Implementation* of :py:func:`hawat.base.VialAppBlueprint.get_module_title`."""
+        """*Implementation* of :py:func:`hawat.base.VialBlueprint.get_module_title`."""
         return lazy_gettext('IDEA event timelines pluggable module')
 
     def register_app(self, app):
         """
-        *Callback method*. Will be called from :py:func:`hawat.base.VialApp.register_blueprint`
+        *Callback method*. Will be called from :py:func:`hawat.base.Vial.register_blueprint`
         method and can be used to customize the Flask application object. Possible
         use cases:
 
         * application menu customization
 
-        :param hawat.base.VialApp app: Flask application to be customized.
+        :param hawat.base.Vial app: Flask application to be customized.
         """
         app.menu_main.add_entry(
             'view',
@@ -237,7 +237,7 @@ class TimelineBlueprint(VialAppBlueprint):
 def get_blueprint():
     """
     Mandatory interface and factory function. This function must return a valid
     instance of :py:class:`hawat.base.VialAppBlueprint` or :py:class:`flask.Blueprint`.
     """
 
     hbp = TimelineBlueprint(
@@ -237,7 +237,7 @@ class TimelineBlueprint(VialAppBlueprint):
     """
     Mandatory interface and factory function. This function must return a valid
-    instance of :py:class:`hawat.base.VialAppBlueprint` or :py:class:`flask.Blueprint`.
+    instance of :py:class:`hawat.base.VialBlueprint` or :py:class:`flask.Blueprint`.
     """
 
diff --git a/lib/hawat/blueprints/users/__init__.py b/lib/hawat/blueprints/users/__init__.py
index 908d67a7743b0d73c0b2d2e16eed1c4232d12fa2..54e2b58398fd00b110022072ce6224b1cf7b23a9 100644
--- a/lib/hawat/blueprints/users/__init__.py
+++ b/lib/hawat/blueprints/users/__init__.py
@@ -48,7 +48,7 @@ import hawat.db
 import hawat.acl
 from hawat.base import HTMLMixin, SQLAlchemyMixin, ItemListView,\
     ItemShowView, ItemCreateView, ItemUpdateView, ItemEnableView,\
-    ItemDisableView, ItemDeleteView, ItemObjectRelationView, VialAppBlueprint
+    ItemDisableView, ItemDeleteView, ItemObjectRelationView, VialBlueprint
 from hawat.blueprints.users.forms import CreateUserAccountForm, UpdateUserAccountForm,\
     AdminUpdateUserAccountForm
 
@@ -994,25 +994,25 @@ class DeleteView(HTMLMixin, SQLAlchemyMixin, ItemDeleteView):  # pylint: disable
 #-------------------------------------------------------------------------------
 
 
-class UsersBlueprint(VialAppBlueprint):
+class UsersBlueprint(VialBlueprint):
     """
     Hawat pluggable module - user accounts.
     """
 
     @classmethod
     def get_module_title(cls):
-        """*Implementation* of :py:func:`hawat.base.VialAppBlueprint.get_module_title`."""
+        """*Implementation* of :py:func:`hawat.base.VialBlueprint.get_module_title`."""
         return lazy_gettext('User account management')
 
     def register_app(self, app):
         """
-        *Callback method*. Will be called from :py:func:`hawat.base.VialApp.register_blueprint`
+        *Callback method*. Will be called from :py:func:`hawat.base.Vial.register_blueprint`
         method and can be used to customize the Flask application object. Possible
         use cases:
 
         * application menu customization
 
-        :param hawat.base.VialApp app: Flask application to be customized.
+        :param hawat.base.Vial app: Flask application to be customized.
         """
         app.menu_main.add_entry(
             'view',
@@ -1038,7 +1038,7 @@ class UsersBlueprint(VialAppBlueprint):
 def get_blueprint():
     """
     Mandatory interface and factory function. This function must return a valid
     instance of :py:class:`hawat.base.VialAppBlueprint` or :py:class:`flask.Blueprint`.
     """
 
     hbp = UsersBlueprint(
@@ -1038,7 +1038,7 @@ class UsersBlueprint(VialAppBlueprint):
     """
     Mandatory interface and factory function. This function must return a valid
-    instance of :py:class:`hawat.base.VialAppBlueprint` or :py:class:`flask.Blueprint`.
+    instance of :py:class:`hawat.base.VialBlueprint` or :py:class:`flask.Blueprint`.
     """
 
diff --git a/lib/hawat/blueprints/whois/__init__.py b/lib/hawat/blueprints/whois/__init__.py
index 32594b6574f63aec1dde74cc5f21348996414c33..2fa5c0a7d95d1004f37bed8f4b513271e4123900 100644
--- a/lib/hawat/blueprints/whois/__init__.py
+++ b/lib/hawat/blueprints/whois/__init__.py
@@ -70,7 +70,7 @@ from mentat.const import tr_
 
 import hawat.db
 import hawat.acl
-from hawat.base import HTMLMixin, AJAXMixin, SnippetMixin, RenderableView, VialAppBlueprint, URLParamsBuilder
+from hawat.base import HTMLMixin, AJAXMixin, SnippetMixin, RenderableView, VialBlueprint, URLParamsBuilder
 from hawat.blueprints.whois.forms import WhoisSearchForm
 
 
@@ -179,25 +179,25 @@ class SnippetSearchView(SnippetMixin, AbstractSearchView):  # pylint: disable=lo
 #-------------------------------------------------------------------------------
 
 
-class WhoisBlueprint(VialAppBlueprint):
+class WhoisBlueprint(VialBlueprint):
     """
     Hawat pluggable module - WHOIS service.
     """
 
     @classmethod
     def get_module_title(cls):
-        """*Implementation* of :py:func:`hawat.base.VialAppBlueprint.get_module_title`."""
+        """*Implementation* of :py:func:`hawat.base.VialBlueprint.get_module_title`."""
         return lazy_gettext('Local WHOIS service')
 
     def register_app(self, app):
         """
-        *Callback method*. Will be called from :py:func:`hawat.base.VialApp.register_blueprint`
+        *Callback method*. Will be called from :py:func:`hawat.base.Vial.register_blueprint`
         method and can be used to customize the Flask application object. Possible
         use cases:
 
         * application menu customization
 
-        :param hawat.base.VialApp app: Flask application to be customized.
+        :param hawat.base.Vial app: Flask application to be customized.
         """
         app.menu_main.add_entry(
             'view',
@@ -233,7 +233,7 @@ class WhoisBlueprint(VialAppBlueprint):
 def get_blueprint():
     """
     Mandatory interface and factory function. This function must return a valid
     instance of :py:class:`hawat.base.VialAppBlueprint` or :py:class:`flask.Blueprint`.
     """
 
     hbp = WhoisBlueprint(
@@ -233,7 +233,7 @@ class WhoisBlueprint(VialAppBlueprint):
     """
     Mandatory interface and factory function. This function must return a valid
-    instance of :py:class:`hawat.base.VialAppBlueprint` or :py:class:`flask.Blueprint`.
+    instance of :py:class:`hawat.base.VialBlueprint` or :py:class:`flask.Blueprint`.
     """
 